@@ -20,7 +20,7 @@ use Data::Reach       qw/reach/;
 use namespace::clean -except => 'meta';
 
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 has 'config'      => (is => 'bare', isa => 'HashRef', required => 1);
 has 'dir'         => (is => 'ro',   isa => 'Str',
@@ -35,6 +35,8 @@ has 'datasources' => (is      => 'ro',
 has 'share_paths' => (is      => 'ro', 
                       isa     => 'ArrayRef',
                       builder => '_share_paths', lazy => 1, auto_deref => 1);
+has 'readonly'    => (is      => 'ro', isa => 'Bool',
+                      builder => '_readonly', lazy => 1);
 
 
 
@@ -59,6 +61,10 @@ sub _title {
   return $self->config(qw/app title/) || 'Welcome to the wonders of AutoCRUD';
 }
 
+sub _readonly {
+  my $self = shift;
+  return $self->config(qw/app readonly/);  
+}
 
 sub _datasources {
   my $self = shift;
@@ -401,6 +407,9 @@ the test file F<t/00_autocrud.t> :
     sqlite_unicode => 1,
   };
   my $config = {
+    app => {
+      name => "SomeName"
+    },
     datasources => {
       SomeDatabase => {
         dbh => {
@@ -719,6 +728,12 @@ as second resort, when components are not found in the application instance
 directory.
 
 
+=head2 readonly
+
+A boolean to restrict actions available to only read from the database.
+The value of readonly boolean is set in YAML configuration file.
+
+
 =head1 METHODS
 
 =head2 new
@@ -888,7 +903,7 @@ L<http://www.codeplex.com/ChinookDatabase>.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2014, 2015 Laurent Dami.
+Copyright 2014-2016 Laurent Dami.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
